#!/bin/bash

set -e

up () {
  loginctl enable-linger $USER
  podman network create pew-net || true

  # Exposed on port 8008 in pew-net
  podman create \
    --name synapse \
    --env TZ=US/Eastern \
    --volume /bigdata/k8s-config/matrix/synapse:/data:rw \
    --network pew-net \
    matrixdotorg/synapse:v1.26.0

  podman generate systemd synapse --restart-policy=always --name > $HOME/.config/systemd/user/synapse.service
  systemctl --user daemon-reload
  systemctl start --user synapse || systemctl restart --user synapse
  systemctl enable --user synapse

  # Exposed on port 80 in pew-net
  podman create \
    --name riot-web \
    --volume /bigdata/k8s-config/matrix/riot-web/config.json:/app/config.json:ro \
    --network pew-net \
    vectorim/element-web:v1.7.20

  podman generate systemd riot-web --restart-policy=always --name > $HOME/.config/systemd/user/riot-web.service
  systemctl --user daemon-reload
  systemctl start --user riot-web || systemctl restart --user riot-web
  systemctl enable --user riot-web
}

down () {
  systemctl stop --user synapse || true
  systemctl disable --user synapse || true
  podman rm synapse || true
  systemctl stop --user riot-web || true
  systemctl disable --user riot-web || true
  podman rm riot-web || true
}

logs () {
  podman logs -f synapse
}

logsr () {
  podman logs -f riot-web
}

$@
